DD developer documentation
==========================

.. toctree::
   :maxdepth: 1
   :caption: Data Dictionary developer guide

   dd_developer_guide
   dm_rules_guidelines

Other documentation for the Data Dictionary can be found on the ITER git and
IDM:

- `Contribution guidelines (git.iter.org)
  <https://github.com/iterorganization/IMAS-Data-Dictionary/blob/develop/CONTRIBUTING.md>`_
- `Data Dictionary Lifecycle (ITER_D_QQYMUK)
  <https://user.iter.org/?uid=QQYMUK>`_
